@@ -20,12 +20,11 @@
 #include "config.h"
 #include "libbiji.h"
 #include "biji-notebook.h"
-#include "biji-error.h"
 
 #include "provider/biji-import-provider.h"
 #include "provider/biji-local-provider.h"
 #include "provider/biji-memo-provider.h"
-#include "provider/biji-own-cloud-provider.h"
+#include "provider/biji-nextcloud-provider.h"
 
 
 struct _BijiManager
@@ -50,11 +49,6 @@ struct _BijiManager
   GFile *location;
   TrackerSparqlConnection *connection;
 
-
-#ifdef BUILD_ZEITGEIST
-  ZeitgeistLog *log;
-#endif /* BUILD_ZEITGEIST */
-
   GdkRGBA color;
 };
 
@@ -181,7 +175,7 @@ load_goa_client (BijiManager *self,
       if (g_strcmp0 (type, "owncloud") == 0)
       {
         g_message ("Loading account %s", goa_account_get_id (account));
-        provider = biji_own_cloud_provider_new (self, object);
+        provider = biji_nextcloud_provider_new (self, object);
         _add_provider (self, provider);
         g_object_unref (provider);
       }
@@ -323,16 +317,6 @@ biji_manager_init (BijiManager *self)
                                            g_free, g_object_unref);
 }
 
-
-#ifdef BUILD_ZEITGEIST
-ZeitgeistLog *
-biji_manager_get_zg_log (BijiManager *self)
-{
-  return self->log;
-}
-#endif /* BUILD_ZEITGEIST */
-
-
 TrackerSparqlConnection *
 biji_manager_get_tracker_connection (BijiManager *self)
 {
@@ -675,10 +659,6 @@ biji_manager_constructed (GObject *object)
 
   G_OBJECT_CLASS (biji_manager_parent_class)->constructed (object);
 
-#ifdef BUILD_ZEITGEIST
-  BIJI_MANAGER (object)->log = biji_zeitgeist_init ();
-#endif /* BUILD_ZEITGEIST */
-
   /* Ensure cache directory for icons */
   filename = g_build_filename (g_get_user_cache_dir (),
                                g_get_application_name (),
